<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>DecoderSndFileFactory</name>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="63"/>
        <source>Sndfile Plugin</source>
        <translation>Sndfile Module</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="66"/>
        <source>PCM Files</source>
        <translation>PCM Bestanden</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="130"/>
        <source>About Sndfile Audio Plugin</source>
        <translation>Over de Sndfile Audio Module</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="131"/>
        <source>Qmmp Sndfile Audio Plugin</source>
        <translation>Sndfile Audio Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="132"/>
        <source>Compiled against</source>
        <translation>Gebouwd tegen</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="133"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
